==> digikam-0.10.0.tar.bz2: digikam-0.10.0/digikam/albumselectwidget.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2009-26-02
 * Description : a widget to select a physical album
 *
 * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef ALBUMSELECTWIDGET_H
#define ALBUMSELECTWIDGET_H

// Qt includes.

#include <QWidget>

// Local includes.

#include "albummanager.h"
#include "searchtextbar.h"

class QTreeWidget;

namespace Digikam
{

class PAlbum;
class AlbumSelectWidgetPriv;

class AlbumSelectWidget : public QWidget
{
    Q_OBJECT

public:

    AlbumSelectWidget(QWidget *parent=0, PAlbum* albumToSelect=0);
    ~AlbumSelectWidget();

    void setCurrentAlbumUrl(const KUrl& albumUrl);
    KUrl currentAlbumUrl() const;

    PAlbum* currentAlbum() const;
    void    setCurrentAlbum(PAlbum *albumToSelect);

    QTreeWidget* albumView() const;

private:

    void populateTreeView(const AlbumList& aList, QTreeWidget *view, PAlbum* albumToSelect);

private Q_SLOTS: 

    void slotSearchTextChanged(const SearchTextSettings&);
    void slotNewAlbum();
    void slotAlbumAdded(Album* a);
    void slotAlbumDeleted(Album* a);
    void slotAlbumsCleared();
    void slotContextMenu();

private:

    AlbumSelectWidgetPriv* const d;
};

}  // namespace Digikam

#endif  // ALBUMSELECTWIDGET_H

==> digikam-1.0.0.tar.bz2: digikam-1.0.0/digikam/albumselectwidget.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2009-26-02
 * Description : a widget to select a physical album
 *
 * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef ALBUMSELECTWIDGET_H
#define ALBUMSELECTWIDGET_H

// Qt includes

#include <QWidget>

// Local includes

#include "albummanager.h"
#include "searchtextbar.h"

class QTreeWidget;

namespace Digikam
{

class PAlbum;
class AlbumSelectWidgetPriv;

class AlbumSelectWidget : public QWidget
{
    Q_OBJECT

public:

    explicit AlbumSelectWidget(QWidget *parent=0, PAlbum* albumToSelect=0);
    ~AlbumSelectWidget();

    void setCurrentAlbumUrl(const KUrl& albumUrl);
    KUrl currentAlbumUrl() const;

    PAlbum* currentAlbum() const;
    void    setCurrentAlbum(PAlbum *albumToSelect);

    QTreeWidget* albumView() const;

Q_SIGNALS:

    void signalAlbumRenamed();

private:

    void populateTreeView(const AlbumList& aList, QTreeWidget *view, PAlbum* albumToSelect);

private Q_SLOTS:

    void slotSearchTextChanged(const SearchTextSettings&);
    void slotNewAlbum();
    void slotAlbumAdded(Album* a);
    void slotAlbumDeleted(Album* a);
    void slotAlbumsCleared();
    void slotAlbumRenamed(Album*);
    void slotContextMenu();

private:

    AlbumSelectWidgetPriv* const d;
};

}  // namespace Digikam

#endif  // ALBUMSELECTWIDGET_H
